
class LightGrouping:
    def __init__(self, lights=[]):
        self.lights = lights

    def add_light(self, light):
        self.lights.append(light)

    def turn_on(self):
        for light in self.lights:
            light.turn_on()

    def turn_off(self):
        for light in self.lights:
            light.turn_off()




class Light:
    def __init__(self, pin_num, gpio):
        self.pin_num = pin_num
        self.gpio = gpio
        self.gpio.setup(self.pin_num, self.gpio.OUT)
        self.state = False

    def turn_on(self):
        if not self.state:
            self.gpio.output(self.pin_num, True)
            self.state = True

    def turn_off(self):
        if self.state:
            self.gpio.output(self.pin_num, False)
            self.state = False



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

from electrician import version

config = {
    'description': 'An abstraction layer to control GPIO devices connected to a raspberry pi',
    'author': 'Brandon Myers',
    'url': 'https://github.com/pwnbus/electrician',
    'download_url': 'https://github.com/pwnbus/electrician/archive/master.zip',
    'author_email': 'pwnbus@mozilla.com',
    'version': version,
    'packages': ['electrician'],
    'scripts': [],
    'name': 'electrician'
}

setup(**config)
